##  Viewing SAP Suggestions
You can view SAP suggestions in reports and create fact sheets from relevant ones. For more details, see [SAP Suggestions in Reports](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports?locale=en-US&state=PRODUCTION&version=CLOUD "View SAP suggestions for AI agents and applications in reports. Create fact sheets from relevant suggestions.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9137b59d0b1d4194beb118442d35feba_LowRes.png)
Viewing SAP Suggestions in a Report
YesNo
Send
